@@ -44,11 +44,11 @@ class BaseView(View):
 
     @classmethod
     def get_path(cls):
-        return cls.schema_class.PATH
+        return cls.SCHEMA_CLASS.PATH
 
     @classmethod
     def get_route_kwargs(cls):
-        return dict(route=cls.get_path(), view=cls.as_view(), name=cls.schema_class.__name__)
+        return dict(route=cls.get_path(), view=cls.as_view(), name=cls.SCHEMA_CLASS.__name__)
 
     # TODO filters for class not per function
     # TODO handle foreign key
@@ -107,6 +107,3 @@ class BaseCrudView(BaseView):
     def get_doc(cls, request):
         crud = cls.schema_class({})
         return render(request, crud.template_path)
-
-
-
